@@ -1,8 +1,8 @@
 /*
  *  Phishing module: domain list implementation.
  *
- *  Copyright (C) 2015 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
- *  Copyright (C) 2007-2008 Sourcefire, Inc.
+ *  Copyright (C) 2013-2019 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
+ *  Copyright (C) 2007-2013 Sourcefire, Inc.
  *
  *  Authors: Török Edvin
  *
@@ -41,40 +41,38 @@
 #include "phish_domaincheck_db.h"
 #include "regex_list.h"
 
-int domainlist_match(const struct cl_engine* engine,char* real_url,const char* display_url,const struct pre_fixup_info* pre_fixup,int hostOnly)
+int domainlist_match(const struct cl_engine* engine, char* real_url, const char* display_url, const struct pre_fixup_info* pre_fixup, int hostOnly)
 {
-	const char* info;
-	int rc = engine->domainlist_matcher ? regex_list_match(engine->domainlist_matcher,real_url,display_url,hostOnly ? pre_fixup : NULL,hostOnly,&info,0) : 0;
-	return rc;
+    const char* info;
+    int rc = engine->domainlist_matcher ? regex_list_match(engine->domainlist_matcher, real_url, display_url, hostOnly ? pre_fixup : NULL, hostOnly, &info, 0) : 0;
+    return rc;
 }
 
 int init_domainlist(struct cl_engine* engine)
 {
-	if(engine) {
-		engine->domainlist_matcher = (struct regex_matcher *) cli_malloc(sizeof(struct regex_matcher));
-		if(!engine->domainlist_matcher) {
+    if (engine) {
+        engine->domainlist_matcher = (struct regex_matcher*)cli_malloc(sizeof(struct regex_matcher));
+        if (!engine->domainlist_matcher) {
             cli_errmsg("Phishcheck: Unable to allocate memory for init_domainlist\n");
-			return CL_EMEM;
+            return CL_EMEM;
         }
 #ifdef USE_MPOOL
-		((struct regex_matcher*)engine->domainlist_matcher)->mempool = engine->mempool;
+        ((struct regex_matcher*)engine->domainlist_matcher)->mempool = engine->mempool;
 #endif
-		return init_regex_list(engine->domainlist_matcher, engine->dconf->other&OTHER_CONF_PREFILTERING);
-	}
-	else
-		return CL_ENULLARG;
+        return init_regex_list(engine->domainlist_matcher, engine->dconf->other & OTHER_CONF_PREFILTERING);
+    } else
+        return CL_ENULLARG;
 }
 
 int is_domainlist_ok(const struct cl_engine* engine)
 {
-	return (engine && engine->domainlist_matcher) ? is_regex_ok(engine->domainlist_matcher) : 1;
+    return (engine && engine->domainlist_matcher) ? is_regex_ok(engine->domainlist_matcher) : 1;
 }
 
 void domainlist_done(struct cl_engine* engine)
 {
-	if(engine && engine->domainlist_matcher) {
-		regex_list_done(engine->domainlist_matcher);
-		free(engine->domainlist_matcher);
-	}
+    if (engine && engine->domainlist_matcher) {
+        regex_list_done(engine->domainlist_matcher);
+        free(engine->domainlist_matcher);
+    }
 }
-
