@@ -1,8 +1,8 @@
 /*
  *  Phishing module: whitelist implementation.
  *
- *  Copyright (C) 2015 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
- *  Copyright (C) 2007-2008 Sourcefire, Inc.
+ *  Copyright (C) 2013-2019 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
+ *  Copyright (C) 2007-2013 Sourcefire, Inc.
  *
  *  Authors: Török Edvin
  *
@@ -21,17 +21,15 @@
  *  MA 02110-1301, USA.
  */
 
-
 #ifndef _PHISH_WHITELIST_H
 #define _PHISH_WHITELIST_H
 
 #include "clamav.h"
 
-int init_whitelist(struct cl_engine* engine);
+cl_error_t init_whitelist(struct cl_engine* engine);
 void whitelist_done(struct cl_engine* engine);
 void whitelist_cleanup(const struct cl_engine* engine);
 int is_whitelist_ok(const struct cl_engine* engine);
-int whitelist_match(const struct cl_engine* engine, char* real_url,const char* display_url,int hostOnly);
+cl_error_t whitelist_match(const struct cl_engine* engine, char* real_url, const char* display_url, int hostOnly);
 
 #endif
-
