@@ -181,10 +181,10 @@ my %CONF = (
     'PACKAGE' => 'PACKAGE_NAME',
     'PACKAGE_BUGREPORT' => '"https://bugzilla.clamav.net/"',
     'PACKAGE_NAME' => '"ClamAV"',
-    'PACKAGE_STRING' => '"ClamAV 0.102.0-devel"',
+    'PACKAGE_STRING' => '"ClamAV 0.102.1"',
     'PACKAGE_TARNAME' => '"clamav"',
     'PACKAGE_URL' => '"https://www.clamav.net/"',
-    'PACKAGE_VERSION' => '"0.102.0-devel"',
+    'PACKAGE_VERSION' => '"0.102.1"',
     'SCANBUFF' => '131072',
     'SETPGRP_VOID' => '1',
     'SIZEOF_INT' => '4',
